==> haskell-language-c-0.8.2-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-language-c.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: language-c
version: 0.8.2
id: language-c-0.8.2-KO6GGy0fbH5KZxtBHfA7kD
key: language-c-0.8.2-KO6GGy0fbH5KZxtBHfA7kD
license: BSD-3-Clause
copyright: LICENSE
maintainer: benedikt.huber@gmail.com
author: AUTHORS
stability: experimental
homepage: http://visq.github.io/language-c/
synopsis: Analysis and generation of C code
description:
    Language C is a haskell library for the analysis and generation of C code.
    It features a complete, well tested parser and pretty printer for all of C99 and a large
    set of C11 and clang/GNU extensions.
category: Language
abi: c94bc5f120f0a77ba02e936153ec7019
exposed: True
exposed-modules:
    Language.C Language.C.Analysis Language.C.Analysis.AstAnalysis
    Language.C.Analysis.Builtins Language.C.Analysis.ConstEval
    Language.C.Analysis.Debug Language.C.Analysis.DeclAnalysis
    Language.C.Analysis.DefTable Language.C.Analysis.Export
    Language.C.Analysis.NameSpaceMap Language.C.Analysis.SemError
    Language.C.Analysis.SemRep Language.C.Analysis.TravMonad
    Language.C.Analysis.TypeCheck Language.C.Analysis.TypeConversions
    Language.C.Analysis.TypeUtils Language.C.Data Language.C.Data.Error
    Language.C.Data.Ident Language.C.Data.InputStream
    Language.C.Data.Name Language.C.Data.Node Language.C.Data.Position
    Language.C.Parser Language.C.Pretty Language.C.Syntax
    Language.C.Syntax.AST Language.C.Syntax.Constants
    Language.C.Syntax.Ops Language.C.Syntax.Utils Language.C.System.GCC
    Language.C.System.Preprocess
hidden-modules: Language.C.Data.RList Language.C.Parser.Builtin
                Language.C.Parser.Lexer Language.C.Parser.ParserMonad
                Language.C.Parser.Tokens Language.C.Parser.Parser
import-dirs: /usr/lib/ghc-8.6.5/site-local/language-c-0.8.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/language-c-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/language-c-0.8.2
hs-libraries: HSlanguage-c-0.8.2-KO6GGy0fbH5KZxtBHfA7kD
depends:
    array-0.5.3.0 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    deepseq-1.4.4.0 directory-1.3.3.0 filepath-1.4.2.1 pretty-1.1.3.6
    process-1.6.5.0 syb-0.7-KRW1LCxdMiCJrmhxCvzo37
haddock-interfaces: /usr/share/doc/haskell-language-c/html/language-c.haddock
haddock-html: /usr/share/doc/haskell-language-c/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-language-c-0.8.2-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-language-c.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: language-c
version: 0.8.2
id: language-c-0.8.2-CvWOC8sEviNIhwt93aRjoe
key: language-c-0.8.2-CvWOC8sEviNIhwt93aRjoe
license: BSD-3-Clause
copyright: LICENSE
maintainer: benedikt.huber@gmail.com
author: AUTHORS
stability: experimental
homepage: http://visq.github.io/language-c/
synopsis: Analysis and generation of C code
description:
    Language C is a haskell library for the analysis and generation of C code.
    It features a complete, well tested parser and pretty printer for all of C99 and a large
    set of C11 and clang/GNU extensions.
category: Language
abi: 779d029c40e1a223e5e36c4291ae6aac
exposed: True
exposed-modules:
    Language.C Language.C.Analysis Language.C.Analysis.AstAnalysis
    Language.C.Analysis.Builtins Language.C.Analysis.ConstEval
    Language.C.Analysis.Debug Language.C.Analysis.DeclAnalysis
    Language.C.Analysis.DefTable Language.C.Analysis.Export
    Language.C.Analysis.NameSpaceMap Language.C.Analysis.SemError
    Language.C.Analysis.SemRep Language.C.Analysis.TravMonad
    Language.C.Analysis.TypeCheck Language.C.Analysis.TypeConversions
    Language.C.Analysis.TypeUtils Language.C.Data Language.C.Data.Error
    Language.C.Data.Ident Language.C.Data.InputStream
    Language.C.Data.Name Language.C.Data.Node Language.C.Data.Position
    Language.C.Parser Language.C.Pretty Language.C.Syntax
    Language.C.Syntax.AST Language.C.Syntax.Constants
    Language.C.Syntax.Ops Language.C.Syntax.Utils Language.C.System.GCC
    Language.C.System.Preprocess
hidden-modules: Language.C.Data.RList Language.C.Parser.Builtin
                Language.C.Parser.Lexer Language.C.Parser.ParserMonad
                Language.C.Parser.Tokens Language.C.Parser.Parser
import-dirs: /usr/lib/ghc-8.6.5/site-local/language-c-0.8.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/language-c-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/language-c-0.8.2
hs-libraries: HSlanguage-c-0.8.2-CvWOC8sEviNIhwt93aRjoe
depends:
    array-0.5.3.0 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    deepseq-1.4.4.0 directory-1.3.3.0 filepath-1.4.2.1 pretty-1.1.3.6
    process-1.6.5.0 syb-0.7.1-1gO4OjQOULM8usUjWwwEyW
haddock-interfaces: /usr/share/doc/haskell-language-c/html/language-c.haddock
haddock-html: /usr/share/doc/haskell-language-c/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
